# -*- coding: utf-8 -*-
"""
Created on Fri Jan 24 16:46:06 2025

@author: CPD
"""
import time

class LedScript:
    def __init__(self):
        self.t_start = 0
        
    def start(self) -> int:
        """
        Start the script and return the initial LED state

        Returns
        -------
        int
            LED Intensity [0,100]
        """
        self.t_start = time.time()
        return 0
        
    def get_state(self, t: None|float=None) -> int:
        """
        Get the LED statefrom an absolute time (relative to when `start` was called)

        Parameters
        ----------
        t : None|float, optional
            Absolute time since epoch or None. 
            If None, the current time will be used (using python `time.time()` 
            The default is None.

        Returns
        -------
        int
            LED Intensity [0,100]
        """
        if t is None:
            t = time.time()
        dt = t - self.t_start
        return self.get_relative_state(dt)
        
    def get_relative_state(self, dt: float) -> int:
        """
        Get the LED state from a script-relative time

        Parameters
        ----------
        dt : float
            Number of seconds from the starting point of the script

        Returns
        -------
        int
            LED Intensity [0,100]
        """
        # TODO remove hard coded script
        if (dt // 3600) % 2 == 0:
            return 100
        return 0